@@ -7,6 +7,10 @@ import platform
 import yaml
 
 # Directories
+custom_modules_dir = None
+custom_system_conf_path = None
+modules_dir_env_key = 'OPENCRAVAT_MD'
+system_conf_path_env_key = 'OPENCRAVAT_SYSTEM_CONF_PATH'
 packagedir = os.path.dirname(os.path.abspath(__file__))
 pl = platform.platform()
 if pl.startswith("Windows"):
@@ -354,3 +358,4 @@ publish_time_fmt = "%Y-%m-%dT%H:%M:%S.%f%z"
 install_tempdir_name = "temp"
 
 cannonical_chroms = ["chr" + str(n) for n in range(1, 23)] + ["chrX", "chrY"]
+default_postaggregator_names = ["tagsampler", "casecontrol", "varmeta", "vcfinfo"]
