@@ -279,7 +279,7 @@ async def get_module_updates (request):
         modules = smodules.split(',')
     else:
         modules = []
-    updates, _, conflicts = au.get_updatable(modules=modules)
+    updates, _, conflicts = await au.get_updatable(modules=modules)
     sconflicts = {}
     for mname, reqd in conflicts.items():
         sconflicts[mname] = {}
@@ -340,6 +340,7 @@ async def update_remote (request):
             response = 'notadmin'
             return web.json_response(response)
     au.mic.update_remote(force=True)
+    au.mic.update_local()
     return web.json_response('done')
 
 def handle_modules_changed():
