@@ -446,7 +446,20 @@ function populateJobTr (job) {
             addEl(viewTd, button);
         }
     } else {
-        viewTd.textContent = statusC;
+        var span = getEl('span')
+        span.textContent = statusC
+        addEl(viewTd, span)
+        if (statusC == 'Aborted' || statusC == 'Error') {
+            var btn = getEl('button')
+            btn.classList.add('butn')
+            btn.textContent = 'Resubmit'
+            btn.addEventListener('click', function(evt) {
+                $.get('/submit/resubmit', {'job_id': job.id, 'job_dir': job.job_dir}).done(function (response) {
+                    setTimeout(function() {populateJobs()}, 3000)
+                })
+            })
+            addEl(viewTd, btn)
+        }
     }
     addEl(jobTr, viewTd);
     var dbTd = getEl('td');
@@ -931,10 +944,13 @@ function inputChangeHandler (event) {
 
 function showJobListPage () {
     var jis = GLOBALS.jobs.slice(jobsListCurStart, jobsListCurEnd);
+    document.querySelector("#jobdivspinnerdiv").classList.remove("hide")
     $.ajax({
         url: '/submit/getjobs',
         data: {'ids': JSON.stringify(jis)},
+        async: true,
         success: function (response) {
+            document.querySelector("#jobdivspinnerdiv").classList.add("hide")
             for (var i=0; i < response.length; i++) {
                 var job = response[i];
                 addJob(job);
@@ -1014,11 +1030,15 @@ function refreshJobsTable () {
 }
 
 function populateAnnotators () {
+    document.querySelector("#annotdivspinnerdiv").classList.remove("hide")
+    document.querySelector("#annotator-group-select-div").classList.remove("show")
     return new Promise((resolve, reject) => {
         $.ajax({
             url:'/submit/annotators',
             type: 'GET',
             success: function (data) {
+                document.querySelector("#annotdivspinnerdiv").classList.add("hide")
+                document.querySelector("#annotator-group-select-div").classList.add("show")
                 GLOBALS.annotators = data
                 setTimeout(function () {
                     buildAnnotatorsSelector();
@@ -1278,17 +1298,17 @@ function buildCheckBoxGroup (checkDatas, parentDiv) {
         checkDiv.setAttribute('name', checkData.name);
         checkDiv.setAttribute('kind', checkData.kind);
         var mouseoverTimer = null;
-        checkDiv.addEventListener('mouseover', function (evt) {
+        checkDiv.addEventListener('contextmenu', function (evt) {
             mouseoverTimer = setTimeout(function () {
                 var dialog = makeModuleDetailDialog(
-                    evt.target.closest('.checkbox-group-element').getAttribute('name'), null, null);
+                    evt.target.closest('.checkbox-group-element').getAttribute('name'), null, null
+                )
                 dialog.style.width = 'calc(100% - 500px)';
                 dialog.style.left = '425px';
                 dialog.style.right = 'inherit';
                 addEl(document.querySelector('#submitdiv'), dialog);
-                //evt.preventDefault();
-                //evt.stopPropagation();
             }, 500)
+            evt.preventDefault();
         })
         checkDiv.addEventListener('mouseout', function (evt) {
             clearTimeout(mouseoverTimer)
@@ -1310,7 +1330,7 @@ function buildCheckBoxGroup (checkDatas, parentDiv) {
         var label = getEl('label');
         label.classList.add('checkbox-container');
         label.textContent = checkData.label + ' ';
-        //label.title = checkData.label + '. Right-click to see details.';
+        label.title = 'Right-click to see details.';
         var check = getEl('input');
         check.setAttribute('type', 'checkbox');
         check.setAttribute('name', checkData.name);
@@ -1852,6 +1872,7 @@ function addListeners () {
     $('#refresh-jobs-table-btn').click(refreshJobsTable);
     $('.threedotsdiv').click(onClickThreeDots);
     $('.jobsdirinput').change(setJobsDir);
+    $('#chaticondiv').click(toggleChatBox)
     document.addEventListener('click', function (evt) {
         if (evt.target.classList.contains('moduledetaildiv-submit-elem') == false && evt.target.closest('.moduledetailbutton') == null ) {
             var div = document.getElementById('moduledetaildiv_submit');
